@@ -34,4 +34,18 @@ def config_supervisor(local_name, remote_name=None):
     put('./config/supervisord/{}.ini'.format(local_name), '/etc/supervisor.d/{}.ini'.format(remote_name))
 
 
+def config_monit(local_name, remote_name=None):
+    """
+    directory must be ./config/supervisor.d/*.ini
+    """
+
+    if remote_name is None:
+        remote_name = local_name
+
+    if ez_env.group != 'ol':
+        local_name += '_' + ez_env.group
+
+    put('./config/monit/{}.conf'.format(local_name), '/etc/monit.d/{}.conf'.format(remote_name))
+
+
 
