@@ -154,7 +154,7 @@ def server_supervisor(user='webuser', tmp='/tmp', log_dir='/logs/supervisor', lo
     # buf = pkg_resources.resource_string('fabez', 'tpl/supervisord.boot')
     # except:
     # buf = open(os.path.join(os.path.dirname(__file__), 'tpl', 'supervisord.boot')).read()
-    #     pass
+    # pass
     #
     # with tempfile.NamedTemporaryFile('w', delete=False) as fh:
     #     print>> fh, buf
@@ -207,10 +207,14 @@ def server_websuite(user='webuser', python_version='3.4.2', only_pypy=True, pypy
 
     io_slowlog('nginx', user)
     # server_nginx(user)
-    server_tengine(user)
+    server_tengine(user=user)
 
-    io_slowlog('supervisor', user)
-    server_supervisor()
+    io_slowlog('tornado', user)
+
+    # io_slowlog('supervisor', user)
+    # server_supervisor()
+
+    server_monit()
 
     if only_pypy:
         py_pypy(pypy_version)
@@ -218,7 +222,6 @@ def server_websuite(user='webuser', python_version='3.4.2', only_pypy=True, pypy
     else:
         py_python(python_version, compatible=compatible, pypy=pypy_version)
 
-
     pip('tornadoez')
     pip('pyjwt')
 
@@ -240,10 +243,7 @@ def server_mysql():
     pass
 
 
-
-
-
-def server_tengine(version=None, user='webuser', tornado=True,process=1,connection=1024):
+def server_tengine(user='webuser', version=None, tornado=True, process=1, connection=1024):
     """
     syslog note
     # need change config use syslog-ng
@@ -262,8 +262,6 @@ def server_tengine(version=None, user='webuser', tornado=True,process=1,connecti
     :return:
     """
 
-    with settings(warn_only=True):
-        run('service tengine stop')
 
 
     utils_baselib()
@@ -273,18 +271,16 @@ def server_tengine(version=None, user='webuser', tornado=True,process=1,connecti
 
     run('chkconfig --level 35 nginx off')
 
-
     if version:
         run('wget http://tengine.taobao.org/download/tengine-{0}.tar.gz -O /tmp/tengine-{0}.tar.gz'.format(version))
     else:
-        cmd_git('/tmp/tengine','https://github.com/nextoa/tengine.git')
+        cmd_git('/tmp/tengine', 'https://github.com/nextoa/tengine.git')
 
     io_slowlog('nginx', user=user)
     io_aircache('nginx', size=1)
 
     run('test -d /usr/local/var/lock || mkdir -p /usr/local/var/lock')
 
-
     with cd('/tmp'):
 
         if version:
@@ -303,7 +299,7 @@ def server_tengine(version=None, user='webuser', tornado=True,process=1,connecti
                     ' --with-http_realip_module'
                     ' --with-http_concat_module '
 
-                    #dir path
+                    # dir path
                     '--pid-path=/usr/local/var/run/nginx.pid --lock-path=/usr/local/var/lock/nginx '
 
                     #file path
@@ -342,10 +338,18 @@ def server_tengine(version=None, user='webuser', tornado=True,process=1,connecti
 
                     ' --with-http_footer_filter_module=shared'.format(user))
 
-            run('make && make install')
-            pass
 
 
+
+            run('make')
+
+            with settings(warn_only=True):
+                run('service tengine stop')
+
+            run('make install')
+
+            pass
+
     try:
         template = pkg_resources.resource_string('fabez', 'tpl/nginx.conf')
     except:
@@ -364,7 +368,6 @@ def server_tengine(version=None, user='webuser', tornado=True,process=1,connecti
 
     os.remove(fh.name)
 
-
     try:
         template = pkg_resources.resource_string('fabez', 'tpl/nginx.start')
     except:
@@ -381,7 +384,6 @@ def server_tengine(version=None, user='webuser', tornado=True,process=1,connecti
 
     os.remove(fh.name)
 
-
     try:
         template = pkg_resources.resource_string('fabez', 'tpl/nginx.sysconfig')
     except:
@@ -398,7 +400,6 @@ def server_tengine(version=None, user='webuser', tornado=True,process=1,connecti
 
     os.remove(fh.name)
 
-
     run('chmod +x  /etc/init.d/tengine')
     run('chkconfig --level 35 tengine on')
     pass
@@ -407,9 +408,39 @@ def server_tengine(version=None, user='webuser', tornado=True,process=1,connecti
 
 
 
+def server_monit(version='5.5-1'):
+
+    # 5.5.1-41
+    # run('yum install monit -y')
+    # with settings(warn_only=True):
+    #     run('for i in `rpm -ql monit`;do rm -rf $i; done;')
+    #     run('rpm -e `rpm -qa | grep -i monit`')
+
+    with settings(warn_only=True):
+        run('rpm -ivh  https://github.com/nextoa/monit-bin/raw/master/monit-{}.el6.rf.x86_64.rpm'.format(version))
+        run('rpm -Uvh  https://github.com/nextoa/monit-bin/raw/master/monit-{}.el6.rf.x86_64.rpm'.format(version))
+    run('chkconfig --level 35 monit on')
+    pass
+
+
+# restart feature
+def restart_web(config=None):
+    # supervisor_restart()
+    if config:
+        config_nginx(config)
+
+    run('service tengine reload')
+    run('service tengine restart')
+
+
+def restart_monit(config=None):
+    if config:
+        config_monit(config)
+    run('service monit restart')
+
+
+
+
 
 
-def supervisor_restart():
-    run('killall supervisord')
-    run('`grep supervisor /etc/rc.local`')
 
